"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RateLimitHandler = void 0;
const cli_utilities_1 = require("@contentstack/cli-utilities");
const common_utilities_1 = require("../utils/common-utilities");
let client;
class RateLimitHandler {
    setClient(managementSDKClient) {
        client = managementSDKClient;
    }
    async setRateLimit(config) {
        var _a;
        const rateLimit = cli_utilities_1.configHandler.get('rateLimit');
        rateLimit.default = Object.assign({}, common_utilities_1.defaultRalteLimitConfig);
        if (config.default) {
            rateLimit[config.org] = Object.assign({}, rateLimit.default);
            cli_utilities_1.configHandler.set('rateLimit', rateLimit);
            cli_utilities_1.cliux.success(`Rate limit reset to default for org: ${config.org}`);
            return;
        }
        if (!rateLimit[config.org]) {
            rateLimit[config.org] = Object.assign({}, rateLimit.default);
        }
        const limitNames = Array.isArray(config['limit-name']) ? config['limit-name'] : [];
        const utilizeValues = Array.isArray(config.utilize) ? config.utilize.map((v) => Number(v)) : [];
        const unavailableLimits = [];
        try {
            const organizations = await client.organization(config.org).fetch({ include_plan: true });
            const features = ((_a = organizations.plan) === null || _a === void 0 ? void 0 : _a.features) || [];
            const limitsToUpdate = Object.assign({}, rateLimit[config.org]);
            const utilizationMap = {};
            limitNames.forEach((name, index) => {
                if (utilizeValues[index] !== undefined) {
                    utilizationMap[name] = utilizeValues[index];
                }
            });
            common_utilities_1.limitNamesConfig.forEach((limitName) => {
                var _a, _b, _c;
                const feature = features.find((f) => f.uid === limitName);
                if (feature) {
                    limitsToUpdate[limitName] = {
                        value: feature.limit || ((_a = rateLimit[config.org][limitName]) === null || _a === void 0 ? void 0 : _a.value) || ((_b = rateLimit.default[limitName]) === null || _b === void 0 ? void 0 : _b.value),
                        utilize: utilizationMap[limitName] || ((_c = common_utilities_1.defaultRalteLimitConfig[limitName]) === null || _c === void 0 ? void 0 : _c.utilize),
                    };
                }
                else {
                    unavailableLimits.push(limitName);
                }
            });
            if (unavailableLimits.length > 0) {
                cli_utilities_1.cliux.print(`You have not subscribed to these limits: ${unavailableLimits.join(', ')}`, {
                    color: 'yellow',
                });
            }
            rateLimit[config.org] = limitsToUpdate;
            cli_utilities_1.configHandler.set('rateLimit', rateLimit);
            cli_utilities_1.cliux.success(`Rate limit has been set successfully for org: ${config.org}`);
            Object.entries(limitsToUpdate).forEach(([limit, { value, utilize }]) => {
                if (!unavailableLimits.includes(limit)) {
                    cli_utilities_1.cliux.success(`${limit}: ${value}(${utilize}%)`);
                }
            });
        }
        catch (error) {
            throw new Error(error);
        }
    }
}
exports.RateLimitHandler = RateLimitHandler;
